grib2io.tables.section4_discipline4 API documentation

# grib2io.tables.section4_discipline4

View Source

      1table_4_2_4_0  = {
      2'0':['Temperature','K','TMPSWP'],
      3'1':['Electron Temperature','K','ELECTMP'],
      4'2':['Proton Temperature','K','PROTTMP'],
      5'3':['Ion Temperature','K','IONTMP'],
      6'4':['Parallel Temperature','K','PRATMP'],
      7'5':['Perpendicular Temperature','K','PRPTMP'],
      8'6-191':['Reserved','unknown','unknown'],
      9'192-254':['Reserved for Local Use','unknown','unknown'],
     10'255':['Missing','unknown','unknown'],
     11}
     12table_4_2_4_1  = {
     13'0':['Velocity Magnitude (Speed)','m s-1','SPEED'],
     14'1':['1st Vector Component of Velocity  (Coordinate system dependent)','m s-1','VEL1'],
     15'2':['2nd Vector Component of Velocity  (Coordinate system dependent)','m s-1','VEL2'],
     16'3':['3rd Vector Component of Velocity  (Coordinate system dependent)','m s-1','VEL3'],
     17'4-191':['Reserved','unknown','unknown'],
     18'192-254':['Reserved for Local Use','unknown','unknown'],
     19'255':['Missing','unknown','unknown'],
     20}
     21table_4_2_4_2  = {
     22'0':['Particle Number Density','m-3','PLSMDEN'],
     23'1':['Electron Density','m-3','ELCDEN'],
     24'2':['Proton Density','m-3','PROTDEN'],
     25'3':['Ion Density','m-3','IONDEN'],
     26'4':['Vertical Electron Content','m-2','VTEC'],
     27'5':['HF Absorption Frequency','Hz','ABSFRQ'],
     28'6':['HF Absorption','dB','ABSRB'],
     29'7':['Spread F','m','SPRDF'],
     30'8':['hF','m','HPRIMF'],
     31'9':['Critical Frequency','Hz','CRTFRQ'],
     32'10':['Scintillation','Numeric','SCINT'],
     33'11-191':['Reserved','unknown','unknown'],
     34'192-254':['Reserved for Local Use','unknown','unknown'],
     35'255':['Missing','unknown','unknown'],
     36}
     37table_4_2_4_3  = {
     38'0':['Magnetic Field Magnitude','T','BTOT'],
     39'1':['1st Vector Component of Magnetic Field','T','BVEC1'],
     40'2':['2nd Vector Component of Magnetic Field','T','BVEC2'],
     41'3':['3rd Vector Component of Magnetic Field','T','BVEC3'],
     42'4':['Electric Field Magnitude','V m-1','ETOT'],
     43'5':['1st Vector Component of Electric Field','V m-1','EVEC1'],
     44'6':['2nd Vector Component of Electric Field','V m-1','EVEC2'],
     45'7':['3rd Vector Component of Electric Field','V m-1','EVEC3'],
     46'8-191':['Reserved','unknown','unknown'],
     47'192-254':['Reserved for Local Use','unknown','unknown'],
     48'255':['Missing','unknown','unknown'],
     49}
     50table_4_2_4_4  = {
     51'0':['Proton Flux (Differential)','(m2 s sr eV)-1','DIFPFLUX'],
     52'1':['Proton Flux (Integral)','(m2 s sr)-1','INTPFLUX'],
     53'2':['Electron Flux (Differential)','(m2 s sr eV)-1','DIFEFLUX'],
     54'3':['Electron Flux (Integral)','(m2 s sr)-1','INTEFLUX'],
     55'4':['Heavy Ion Flux (Differential)','(m2 s sr eV / nuc)-1','DIFIFLUX'],
     56'5':['Heavy Ion Flux (iIntegral)','(m2 s sr)-1','INTIFLUX'],
     57'6':['Cosmic Ray Neutron Flux','h-1','NTRNFLUX'],
     58'7-191':['Reserved','unknown','unknown'],
     59'192-254':['Reserved for Local Use','unknown','unknown'],
     60'255':['Missing','unknown','unknown'],
     61}
     62table_4_2_4_5  = {
     63'0-191':['Reserved','unknown','unknown'],
     64'192-254':['Reserved for Local Use','unknown','unknown'],
     65'255':['Missing','unknown','unknown'],
     66}
     67table_4_2_4_6  = {
     68'0':['Integrated Solar Irradiance','W m-2','TSI'],
     69'1':['Solar X-ray Flux (XRS Long)','W m-2','XLONG'],
     70'2':['Solar X-ray Flux (XRS Short)','W m-2','XSHRT'],
     71'3':['Solar EUV Irradiance','W m-2','EUVIRR'],
     72'4':['Solar Spectral Irradiance','W m-2 nm-1','SPECIRR'],
     73'5':['F10.7','W m-2 Hz-1','F107'],
     74'6':['Solar Radio Emissions','W m-2 Hz-1','SOLRF'],
     75'7-191':['Reserved','unknown','unknown'],
     76'192-254':['Reserved for Local Use','unknown','unknown'],
     77'255':['Missing','unknown','unknown'],
     78}
     79table_4_2_4_7  = {
     80'0':['Limb Intensity','m-2 s-1','LMBINT'],
     81'1':['Disk Intensity','m-2 s-1','DSKINT'],
     82'2':['Disk Intensity Day','m-2 s-1','DSKDAY'],
     83'3':['Disk Intensity Night','m-2 s-1','DSKNGT'],
     84'4-191':['Reserved','unknown','unknown'],
     85'192-254':['Reserved for Local Use','unknown','unknown'],
     86'255':['Missing','unknown','unknown'],
     87}
     88table_4_2_4_8  = {
     89'0':['X-Ray Radiance','W sr-1 m-2','XRAYRAD'],
     90'1':['EUV Radiance','W sr-1 m-2','EUVRAD'],
     91'2':['H-Alpha Radiance','W sr-1 m-2','HARAD'],
     92'3':['White Light Radiance','W sr-1 m-2','WHTRAD'],
     93'4':['CaII-K Radiance','W sr-1 m-2','CAIIRAD'],
     94'5':['White Light Coronagraph Radiance','W sr-1 m-2','WHTCOR'],
     95'6':['Heliospheric Radiance','W sr-1 m-2','HELCOR'],
     96'7':['Thematic Mask','Numeric','MASK'],
     97'8-191':['Reserved','unknown','unknown'],
     98'192-254':['Reserved for Local Use','unknown','unknown'],
     99'255':['Missing','unknown','unknown'],
    100}
    101table_4_2_4_9  = {
    102'0':['Pedersen Conductivity','S m-1','SIGPED'],
    103'1':['Hall Conductivity','S m-1','SIGHAL'],
    104'2':['Parallel Conductivity','S m-1','SIGPAR'],
    105'3-191':['Reserved','unknown','unknown'],
    106'192-254':['Reserved for Local Use','unknown','unknown'],
    107'255':['Missing','unknown','unknown'],
    108}